EventSourceConfiguration class

Describes mapping between an Amazon Kinesis stream and a Lambda function.

Constructors

EventSourceConfiguration({int? batchSize, String? eventSource, String? functionName, bool? isActive, DateTime? lastModified, Map<String, String>? parameters, String? role, String? status, String? uuid})
EventSourceConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

batchSize → int?
The largest number of records that AWS Lambda will POST in the invocation request to your function.
final
eventSource → String?
The Amazon Resource Name (ARN) of the Amazon Kinesis stream that is the source of events.
final
functionName → String?
The Lambda function to invoke when AWS Lambda detects an event on the stream.
final
hashCode → int
The hash code for this object.
no setterinherited
isActive → bool?
Indicates whether the event source mapping is currently honored. Events are only processes if IsActive is true.
final
lastModified → DateTime?
The UTC time string indicating the last time the event mapping was updated.
final
parameters → Map<String, String>?
The map (key-value pairs) defining the configuration for AWS Lambda to use when reading the event source.
final
role → String?
The ARN of the IAM role (invocation role) that AWS Lambda can assume to read from the stream and invoke the function.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
The description of the health of the event source mapping. Valid values are: "PENDING", "OK", and "PROBLEM:message". Initially this staus is "PENDING". When AWS Lambda begins processing events, it changes the status to "OK".
final
uuid → String?
The AWS Lambda assigned opaque identifier for the mapping.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited