FunctionCodeLocation class

The object for the Lambda function location.

Constructors

FunctionCodeLocation({String? location, String? repositoryType})
FunctionCodeLocation.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
location → String?
The presigned URL you can use to download the function's .zip file that you previously uploaded. The URL is valid for up to 10 minutes.
final
repositoryType → String?
The repository from which you can download the function.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited