FunctionConfiguration class

A complex type that describes function metadata.

Constructors

FunctionConfiguration({int? codeSize, String? configurationId, String? description, String? functionARN, String? functionName, String? handler, DateTime? lastModified, int? memorySize, Mode? mode, String? role, Runtime? runtime, int? timeout})
FunctionConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

codeSize → int?
The size, in bytes, of the function .zip file you uploaded.
final
configurationId → String?
A Lambda-assigned unique identifier for the current function code and related configuration.
final
description → String?
The user-provided description.
final
functionARN → String?
The Amazon Resource Name (ARN) assigned to the function.
final
functionName → String?
The name of the function.
final
handler → String?
The function Lambda calls to begin executing your function.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModified → DateTime?
The timestamp of the last time you updated the function.
final
memorySize → int?
The memory size, in MB, you configured for the function. Must be a multiple of 64 MB.
final
mode → Mode?
The type of the Lambda function you uploaded.
final
role → String?
The Amazon Resource Name (ARN) of the IAM role that Lambda assumes when it executes your function to access any other Amazon Web Services (AWS) resources.
final
runtime → Runtime?
The runtime environment for the Lambda function.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeout → int?
The function execution time at which Lambda should terminate the function. Because the execution time has cost implications, we recommend you set this value based on your expected execution time. The default is 3 seconds.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited