GetFunctionResponse class

This response contains the object for AWS Lambda function location (see API_FunctionCodeLocation

Constructors

GetFunctionResponse({FunctionCodeLocation? code, FunctionConfiguration? configuration})
GetFunctionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

code → FunctionCodeLocation?
final
configuration → FunctionConfiguration?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited