InvalidRequestContentException class

The request body could not be parsed as JSON.

Implemented types

Constructors

InvalidRequestContentException({String? type, String? message})
InvalidRequestContentException.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited