InvokeAsyncResponse class

Upon success, it returns empty response. Otherwise, throws an exception.

Constructors

InvokeAsyncResponse({int? status})
InvokeAsyncResponse.fromJson(Map<String, dynamic> _)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → int?
It will be 202 upon success.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited