ServiceException class

The AWS Lambda service encountered an internal error.

Implemented types

Constructors

ServiceException({String? message, String? type})
ServiceException.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited