AccountLimit class

Limits that are related to concurrency and storage. All file and storage sizes are in bytes.

Constructors

AccountLimit({int? codeSizeUnzipped, int? codeSizeZipped, int? concurrentExecutions, int? totalCodeSize, int? unreservedConcurrentExecutions})
AccountLimit.fromJson(Map<String, dynamic> json)
factory

Properties

codeSizeUnzipped → int?
The maximum size of a function's deployment package and layers when they're extracted.
final
codeSizeZipped → int?
The maximum size of a deployment package when it's uploaded directly to AWS Lambda. Use Amazon S3 for larger files.
final
concurrentExecutions → int?
The maximum number of simultaneous function executions.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCodeSize → int?
The amount of storage space that you can use for all deployment packages and layer archives.
final
unreservedConcurrentExecutions → int?
The maximum number of simultaneous function executions, minus the capacity that's reserved for individual functions with PutFunctionConcurrency.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited