AccountUsage class

The number of functions and amount of storage in use.

Constructors

AccountUsage({int? functionCount, int? totalCodeSize})
AccountUsage.fromJson(Map<String, dynamic> json)
factory

Properties

functionCount → int?
The number of Lambda functions.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCodeSize → int?
The amount of storage space, in bytes, that's being used by deployment packages and layer archives.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited