AliasConfiguration class

Provides configuration information about a Lambda function alias.

Constructors

AliasConfiguration({String? aliasArn, String? description, String? functionVersion, String? name, String? revisionId, AliasRoutingConfiguration? routingConfig})
AliasConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

aliasArn → String?
The Amazon Resource Name (ARN) of the alias.
final
description → String?
A description of the alias.
final
functionVersion → String?
The function version that the alias invokes.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the alias.
final
revisionId → String?
A unique identifier that changes when you update the alias.
final
routingConfig → AliasRoutingConfiguration?
The routing configuration of the alias.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited