AliasRoutingConfiguration class

The traffic-shifting configuration of a Lambda function alias.

Constructors

AliasRoutingConfiguration({Map<String, double>? additionalVersionWeights})
AliasRoutingConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

additionalVersionWeights → Map<String, double>?
The second version, and the percentage of traffic that's routed to it.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited