CodeSigningConfig class

Details about a Code signing configuration.

Constructors

CodeSigningConfig({required AllowedPublishers allowedPublishers, required String codeSigningConfigArn, required String codeSigningConfigId, required CodeSigningPolicies codeSigningPolicies, required String lastModified, String? description})
CodeSigningConfig.fromJson(Map<String, dynamic> json)
factory

Properties

allowedPublishers → AllowedPublishers
List of allowed publishers.
final
codeSigningConfigArn → String
The Amazon Resource Name (ARN) of the Code signing configuration.
final
codeSigningConfigId → String
Unique identifer for the Code signing configuration.
final
codeSigningPolicies → CodeSigningPolicies
The code signing policy controls the validation failure action for signature mismatch or expiry.
final
description → String?
Code signing configuration description.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModified → String
The date and time that the Code signing configuration was last modified, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited