DestinationConfig class

A configuration object that specifies the destination of an event after Lambda processes it.

Constructors

DestinationConfig({OnFailure? onFailure, OnSuccess? onSuccess})
DestinationConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
onFailure → OnFailure?
The destination configuration for failed invocations.
final
onSuccess → OnSuccess?
The destination configuration for successful invocations.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited