EnvironmentError class

Error messages for environment variables that couldn't be applied.

Constructors

EnvironmentError({String? errorCode, String? message})
EnvironmentError.fromJson(Map<String, dynamic> json)
factory

Properties

errorCode → String?
The error code.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
The error message.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited