EventSourceMappingConfiguration class

A mapping between an AWS resource and an AWS Lambda function. See CreateEventSourceMapping for details.

Constructors

EventSourceMappingConfiguration({int? batchSize, bool? bisectBatchOnFunctionError, DestinationConfig? destinationConfig, String? eventSourceArn, String? functionArn, List<FunctionResponseType>? functionResponseTypes, DateTime? lastModified, String? lastProcessingResult, int? maximumBatchingWindowInSeconds, int? maximumRecordAgeInSeconds, int? maximumRetryAttempts, int? parallelizationFactor, List<String>? queues, SelfManagedEventSource? selfManagedEventSource, List<SourceAccessConfiguration>? sourceAccessConfigurations, EventSourcePosition? startingPosition, DateTime? startingPositionTimestamp, String? state, String? stateTransitionReason, List<String>? topics, int? tumblingWindowInSeconds, String? uuid})
EventSourceMappingConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

batchSize → int?
The maximum number of items to retrieve in a single batch.
final
bisectBatchOnFunctionError → bool?
(Streams) If the function returns an error, split the batch in two and retry. The default value is false.
final
destinationConfig → DestinationConfig?
(Streams) An Amazon SQS queue or Amazon SNS topic destination for discarded records.
final
eventSourceArn → String?
The Amazon Resource Name (ARN) of the event source.
final
functionArn → String?
The ARN of the Lambda function.
final
functionResponseTypes → List<FunctionResponseType>?
(Streams) A list of current response type enums applied to the event source mapping.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModified → DateTime?
The date that the event source mapping was last updated, or its state changed.
final
lastProcessingResult → String?
The result of the last AWS Lambda invocation of your Lambda function.
final
maximumBatchingWindowInSeconds → int?
(Streams and SQS standard queues) The maximum amount of time to gather records before invoking the function, in seconds. The default value is zero.
final
maximumRecordAgeInSeconds → int?
(Streams) Discard records older than the specified age. The default value is infinite (-1). When set to infinite (-1), failed records are retried until the record expires.
final
maximumRetryAttempts → int?
(Streams) Discard records after the specified number of retries. The default value is infinite (-1). When set to infinite (-1), failed records are retried until the record expires.
final
parallelizationFactor → int?
(Streams) The number of batches to process from each shard concurrently. The default value is 1.
final
queues → List<String>?
(MQ) The name of the Amazon MQ broker destination queue to consume.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selfManagedEventSource → SelfManagedEventSource?
The Self-Managed Apache Kafka cluster for your event source.
final
sourceAccessConfigurations → List<SourceAccessConfiguration>?
An array of the authentication protocol, or the VPC components to secure your event source.
final
startingPosition → EventSourcePosition?
The position in a stream from which to start reading. Required for Amazon Kinesis, Amazon DynamoDB, and Amazon MSK Streams sources. AT_TIMESTAMP is only supported for Amazon Kinesis streams.
final
startingPositionTimestamp → DateTime?
With StartingPosition set to AT_TIMESTAMP, the time from which to start reading.
final
state → String?
The state of the event source mapping. It can be one of the following: Creating, Enabling, Enabled, Disabling, Disabled, Updating, or Deleting.
final
stateTransitionReason → String?
Indicates whether the last change to the event source mapping was made by a user, or by the Lambda service.
final
topics → List<String>?
The name of the Kafka topic.
final
tumblingWindowInSeconds → int?
(Streams) The duration of a processing window in seconds. The range is between 1 second up to 15 minutes.
final
uuid → String?
The identifier of the event source mapping.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited