FileSystemConfig class

Details about the connection between a Lambda function and an Amazon EFS file system.

Constructors

FileSystemConfig({required String arn, required String localMountPath})
FileSystemConfig.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String
The Amazon Resource Name (ARN) of the Amazon EFS access point that provides access to the file system.
final
hashCode → int
The hash code for this object.
no setterinherited
localMountPath → String
The path where the function can access the file system, starting with /mnt/.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited