FunctionCode class

The code for the Lambda function. You can specify either an object in Amazon S3, upload a .zip file archive deployment package directly, or specify the URI of a container image.

Constructors

FunctionCode({String? imageUri, String? s3Bucket, String? s3Key, String? s3ObjectVersion, Uint8List? zipFile})

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageUri → String?
URI of a container image in the Amazon ECR registry.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3Bucket → String?
An Amazon S3 bucket in the same AWS Region as your function. The bucket can be in a different AWS account.
final
s3Key → String?
The Amazon S3 key of the deployment package.
final
s3ObjectVersion → String?
For versioned objects, the version of the deployment package object to use.
final
zipFile → Uint8List?
The base64-encoded contents of the deployment package. AWS SDK and AWS CLI clients handle the encoding for you.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited