FunctionCodeLocation class

Details about a function's deployment package.

Constructors

FunctionCodeLocation({String? imageUri, String? location, String? repositoryType, String? resolvedImageUri})
FunctionCodeLocation.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageUri → String?
URI of a container image in the Amazon ECR registry.
final
location → String?
A presigned URL that you can use to download the deployment package.
final
repositoryType → String?
The service that's hosting the file.
final
resolvedImageUri → String?
The resolved URI for the image.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited