FunctionConfiguration class

Details about a function's configuration.

Constructors

FunctionConfiguration({String? codeSha256, int? codeSize, DeadLetterConfig? deadLetterConfig, String? description, EnvironmentResponse? environment, List<FileSystemConfig>? fileSystemConfigs, String? functionArn, String? functionName, String? handler, ImageConfigResponse? imageConfigResponse, String? kMSKeyArn, String? lastModified, LastUpdateStatus? lastUpdateStatus, String? lastUpdateStatusReason, LastUpdateStatusReasonCode? lastUpdateStatusReasonCode, List<Layer>? layers, String? masterArn, int? memorySize, PackageType? packageType, String? revisionId, String? role, Runtime? runtime, String? signingJobArn, String? signingProfileVersionArn, State? state, String? stateReason, StateReasonCode? stateReasonCode, int? timeout, TracingConfigResponse? tracingConfig, String? version, VpcConfigResponse? vpcConfig})
FunctionConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

codeSha256 → String?
The SHA256 hash of the function's deployment package.
final
codeSize → int?
The size of the function's deployment package, in bytes.
final
deadLetterConfig → DeadLetterConfig?
The function's dead letter queue.
final
description → String?
The function's description.
final
environment → EnvironmentResponse?
The function's environment variables.
final
fileSystemConfigs → List<FileSystemConfig>?
Connection settings for an Amazon EFS file system.
final
functionArn → String?
The function's Amazon Resource Name (ARN).
final
functionName → String?
The name of the function.
final
handler → String?
The function that Lambda calls to begin executing your function.
final
hashCode → int
The hash code for this object.
no setterinherited
imageConfigResponse → ImageConfigResponse?
The function's image configuration values.
final
kMSKeyArn → String?
The KMS key that's used to encrypt the function's environment variables. This key is only returned if you've configured a customer managed CMK.
final
lastModified → String?
The date and time that the function was last updated, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
final
lastUpdateStatus → LastUpdateStatus?
The status of the last update that was performed on the function. This is first set to Successful after function creation completes.
final
lastUpdateStatusReason → String?
The reason for the last update that was performed on the function.
final
lastUpdateStatusReasonCode → LastUpdateStatusReasonCode?
The reason code for the last update that was performed on the function.
final
layers → List<Layer>?
The function's layers.
final
masterArn → String?
For Lambda@Edge functions, the ARN of the master function.
final
memorySize → int?
The amount of memory available to the function at runtime.
final
packageType → PackageType?
The type of deployment package. Set to Image for container image and set Zip for .zip file archive.
final
revisionId → String?
The latest updated revision of the function or alias.
final
role → String?
The function's execution role.
final
runtime → Runtime?
The runtime environment for the Lambda function.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signingJobArn → String?
The ARN of the signing job.
final
signingProfileVersionArn → String?
The ARN of the signing profile version.
final
state → State?
The current state of the function. When the state is Inactive, you can reactivate the function by invoking it.
final
stateReason → String?
The reason for the function's current state.
final
stateReasonCode → StateReasonCode?
The reason code for the function's current state. When the code is Creating, you can't invoke or modify the function.
final
timeout → int?
The amount of time in seconds that Lambda allows a function to run before stopping it.
final
tracingConfig → TracingConfigResponse?
The function's AWS X-Ray tracing configuration.
final
version → String?
The version of the Lambda function.
final
vpcConfig → VpcConfigResponse?
The function's networking configuration.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited