FunctionEventInvokeConfig class

Constructors

FunctionEventInvokeConfig({DestinationConfig? destinationConfig, String? functionArn, DateTime? lastModified, int? maximumEventAgeInSeconds, int? maximumRetryAttempts})
FunctionEventInvokeConfig.fromJson(Map<String, dynamic> json)
factory

Properties

destinationConfig → DestinationConfig?
A destination for events after they have been sent to a function for processing.
final
functionArn → String?
The Amazon Resource Name (ARN) of the function.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModified → DateTime?
The date and time that the configuration was last updated.
final
maximumEventAgeInSeconds → int?
The maximum age of a request that Lambda sends to a function for processing.
final
maximumRetryAttempts → int?
The maximum number of times to retry when the function returns an error.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited