GetAccountSettingsResponse class

Constructors

GetAccountSettingsResponse({AccountLimit? accountLimit, AccountUsage? accountUsage})
GetAccountSettingsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

accountLimit → AccountLimit?
Limits that are related to concurrency and code storage.
final
accountUsage → AccountUsage?
The number of functions and amount of storage in use.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited