GetFunctionResponse class

Constructors

GetFunctionResponse({FunctionCodeLocation? code, Concurrency? concurrency, FunctionConfiguration? configuration, Map<String, String>? tags})
GetFunctionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

code → FunctionCodeLocation?
The deployment package of the function or version.
final
concurrency → Concurrency?
The function's reserved concurrency.
final
configuration → FunctionConfiguration?
The configuration of the function or version.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → Map<String, String>?
The function's tags.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited