GetLayerVersionResponse class

Constructors

GetLayerVersionResponse({List<Runtime>? compatibleRuntimes, LayerVersionContentOutput? content, String? createdDate, String? description, String? layerArn, String? layerVersionArn, String? licenseInfo, int? version})
GetLayerVersionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

compatibleRuntimes → List<Runtime>?
The layer's compatible runtimes.
final
content → LayerVersionContentOutput?
Details about the layer version.
final
createdDate → String?
The date that the layer version was created, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
final
description → String?
The description of the version.
final
hashCode → int
The hash code for this object.
no setterinherited
layerArn → String?
The ARN of the layer.
final
layerVersionArn → String?
The ARN of the layer version.
final
licenseInfo → String?
The layer's software license.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → int?
The version number.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited