GetProvisionedConcurrencyConfigResponse class

Constructors

GetProvisionedConcurrencyConfigResponse({int? allocatedProvisionedConcurrentExecutions, int? availableProvisionedConcurrentExecutions, String? lastModified, int? requestedProvisionedConcurrentExecutions, ProvisionedConcurrencyStatusEnum? status, String? statusReason})
GetProvisionedConcurrencyConfigResponse.fromJson(Map<String, dynamic> json)
factory

Properties

allocatedProvisionedConcurrentExecutions → int?
The amount of provisioned concurrency allocated.
final
availableProvisionedConcurrentExecutions → int?
The amount of provisioned concurrency available.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModified → String?
The date and time that a user last updated the configuration, in ISO 8601 format.
final
requestedProvisionedConcurrentExecutions → int?
The amount of provisioned concurrency requested.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → ProvisionedConcurrencyStatusEnum?
The status of the allocation process.
final
statusReason → String?
For failed allocations, the reason that provisioned concurrency could not be allocated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited