ImageConfig class

Configuration values that override the container image Dockerfile settings. See Container settings.

Constructors

ImageConfig({List<String>? command, List<String>? entryPoint, String? workingDirectory})
ImageConfig.fromJson(Map<String, dynamic> json)
factory

Properties

command → List<String>?
Specifies parameters that you want to pass in with ENTRYPOINT.
final
entryPoint → List<String>?
Specifies the entry point to their application, which is typically the location of the runtime executable.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workingDirectory → String?
Specifies the working directory.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited