ImageConfigError class

Error response to GetFunctionConfiguration.

Constructors

ImageConfigError({String? errorCode, String? message})
ImageConfigError.fromJson(Map<String, dynamic> json)
factory

Properties

errorCode → String?
Error code.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
Error message.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited