ImageConfigResponse class

Response to GetFunctionConfiguration request.

Constructors

ImageConfigResponse({ImageConfigError? error, ImageConfig? imageConfig})
ImageConfigResponse.fromJson(Map<String, dynamic> json)
factory

Properties

error → ImageConfigError?
Error response to GetFunctionConfiguration.
final
hashCode → int
The hash code for this object.
no setterinherited
imageConfig → ImageConfig?
Configuration values that override the container image Dockerfile.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited