InvokeAsyncResponse class

A success response (202 Accepted) indicates that the request is queued for invocation.

Annotations

Constructors

InvokeAsyncResponse({int? status})
InvokeAsyncResponse.fromJson(Map<String, dynamic> _)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → int?
The status code.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited