Layer class

Constructors

Layer({String? arn, int? codeSize, String? signingJobArn, String? signingProfileVersionArn})
Layer.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The Amazon Resource Name (ARN) of the function layer.
final
codeSize → int?
The size of the layer archive in bytes.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signingJobArn → String?
The Amazon Resource Name (ARN) of a signing job.
final
signingProfileVersionArn → String?
The Amazon Resource Name (ARN) for a signing profile version.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited