LayerVersionContentInput class

A ZIP archive that contains the contents of an AWS Lambda layer. You can specify either an Amazon S3 location, or upload a layer archive directly.

Constructors

LayerVersionContentInput({String? s3Bucket, String? s3Key, String? s3ObjectVersion, Uint8List? zipFile})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3Bucket → String?
The Amazon S3 bucket of the layer archive.
final
s3Key → String?
The Amazon S3 key of the layer archive.
final
s3ObjectVersion → String?
For versioned objects, the version of the layer archive object to use.
final
zipFile → Uint8List?
The base64-encoded contents of the layer archive. AWS SDK and AWS CLI clients handle the encoding for you.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited