LayerVersionsListItem class

Details about a version of an AWS Lambda layer.

Constructors

LayerVersionsListItem({List<Runtime>? compatibleRuntimes, String? createdDate, String? description, String? layerVersionArn, String? licenseInfo, int? version})
LayerVersionsListItem.fromJson(Map<String, dynamic> json)
factory

Properties

compatibleRuntimes → List<Runtime>?
The layer's compatible runtimes.
final
createdDate → String?
The date that the version was created, in ISO 8601 format. For example, 2018-11-27T15:10:45.123+0000.
final
description → String?
The description of the version.
final
hashCode → int
The hash code for this object.
no setterinherited
layerVersionArn → String?
The ARN of the layer version.
final
licenseInfo → String?
The layer's open-source license.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → int?
The version number.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited