LayersListItem class

Details about an AWS Lambda layer.

Constructors

LayersListItem({LayerVersionsListItem? latestMatchingVersion, String? layerArn, String? layerName})
LayersListItem.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
latestMatchingVersion → LayerVersionsListItem?
The newest version of the layer.
final
layerArn → String?
The Amazon Resource Name (ARN) of the function layer.
final
layerName → String?
The name of the layer.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited