ListLayersResponse class

Constructors

ListLayersResponse({List<LayersListItem>? layers, String? nextMarker})
ListLayersResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
layers → List<LayersListItem>?
A list of function layers.
final
nextMarker → String?
A pagination token returned when the response doesn't contain all layers.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited