OnSuccess class

A destination for events that were processed successfully.

Constructors

OnSuccess({String? destination})
OnSuccess.fromJson(Map<String, dynamic> json)
factory

Properties

destination → String?
The Amazon Resource Name (ARN) of the destination resource.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited