PutFunctionCodeSigningConfigResponse class

Constructors

PutFunctionCodeSigningConfigResponse({required String codeSigningConfigArn, required String functionName})
PutFunctionCodeSigningConfigResponse.fromJson(Map<String, dynamic> json)
factory

Properties

codeSigningConfigArn → String
The The Amazon Resource Name (ARN) of the code signing configuration.
final
functionName → String
The name of the Lambda function.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited