VpcConfig class

The VPC security groups and subnets that are attached to a Lambda function. For more information, see VPC Settings.

Constructors

VpcConfig({List<String>? securityGroupIds, List<String>? subnetIds})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityGroupIds → List<String>?
A list of VPC security groups IDs.
final
subnetIds → List<String>?
A list of VPC subnet IDs.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited